Crate git_sshripped_recipient

Crate git_sshripped_recipient 

Structs

GithubFetchMetadata
GithubFetchOptions
GithubTeamMembers
GithubUserKeys

Enums

GithubAuthMode
GithubBackend

Functions

add_recipient_from_public_key
Add a recipient from an SSH public key line.
add_recipients_from_github_keys
Add recipients from a GitHub keys URL.
add_recipients_from_github_source
Add recipients from a GitHub source URL or username.
add_recipients_from_github_source_with_options
Add recipients from a GitHub source with explicit options.
add_recipients_from_github_username
Add recipients from a GitHub username using environment-based options.
add_recipients_from_github_username_with_options
Add recipients from a GitHub username with explicit options.
fetch_github_team_members
Fetch members of a GitHub team using environment-based options.
fetch_github_team_members_with_options
Fetch members of a GitHub team with explicit options.
fetch_github_user_keys
Fetch SSH public keys for a GitHub user using environment-based options.
fetch_github_user_keys_with_options
Fetch SSH public keys for a GitHub user with explicit options.
fingerprint_for_public_key_line
list_recipients
List all registered recipients for a repository.
recipient_store_dir
remove_recipient_by_fingerprint
Remove a single recipient and its wrapped key by fingerprint.
remove_recipients_by_fingerprints
Remove recipients by their fingerprints.
wrap_repo_key_for_all_recipients
Wrap the repo key for all registered recipients.
wrap_repo_key_for_recipient
Wrap the repo key for a single recipient using age encryption.
wrapped_store_dir