Structs
Enums
Functions
- add_
recipient_ from_ public_ key - Add a recipient from an SSH public key line.
- add_
recipients_ from_ github_ keys - Add recipients from a GitHub keys URL.
- add_
recipients_ from_ github_ source - Add recipients from a GitHub source URL or username.
- add_
recipients_ from_ github_ source_ with_ options - Add recipients from a GitHub source with explicit options.
- add_
recipients_ from_ github_ username - Add recipients from a GitHub username using environment-based options.
- add_
recipients_ from_ github_ username_ with_ options - Add recipients from a GitHub username with explicit options.
- fetch_
github_ team_ members - Fetch members of a GitHub team using environment-based options.
- fetch_
github_ team_ members_ with_ options - Fetch members of a GitHub team with explicit options.
- fetch_
github_ user_ keys - Fetch SSH public keys for a GitHub user using environment-based options.
- fetch_
github_ user_ keys_ with_ options - Fetch SSH public keys for a GitHub user with explicit options.
- fingerprint_
for_ public_ key_ line - list_
recipients - List all registered recipients for a repository.
- recipient_
store_ dir - remove_
recipient_ by_ fingerprint - Remove a single recipient and its wrapped key by fingerprint.
- remove_
recipients_ by_ fingerprints - Remove recipients by their fingerprints.
- wrap_
repo_ key_ for_ all_ recipients - Wrap the repo key for all registered recipients.
- wrap_
repo_ key_ for_ recipient - Wrap the repo key for a single recipient using age encryption.
- wrapped_
store_ dir